Mathematical functions
======================

Mpmath implements the standard functions from Python's ``math`` and ``cmath`` modules, for both real and complex numbers and with arbitrary precision. Many other functions are also available in mpmath, including commonly-used variants of standard functions (such as the alternative trigonometric functions sec, csc, cot), but also a large number of "special functions" such as the gamma function, the Riemann zeta function, error functions, Bessel functions, etc.

.. toctree::
   :maxdepth: 2

   constants.rst
   powers.rst
   trigonometric.rst
   hyperbolic.rst
   gamma.rst
   expintegrals.rst
   bessel.rst
   orthogonal.rst
   hypergeometric.rst
   elliptic.rst
   zeta.rst
   numtheory.rst
   qfunctions.rst
